summaryrefslogtreecommitdiffstats
path: root/lib/util/tdescriptactionmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/util/tdescriptactionmanager.h')
-rw-r--r--lib/util/tdescriptactionmanager.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/lib/util/tdescriptactionmanager.h b/lib/util/tdescriptactionmanager.h
index c2e43238..6c68457b 100644
--- a/lib/util/tdescriptactionmanager.h
+++ b/lib/util/tdescriptactionmanager.h
@@ -24,14 +24,14 @@
#include <tqobject.h>
#include <tqptrlist.h>
-class KAction;
-class KActionCollection;
+class TDEAction;
+class TDEActionCollection;
class KScriptInterface;
class KScriptActionManager;
class TQTimer;
/**
* Connects a KAction to a script runner.
*
* @author ian geiser geiseri@sourcextreme.com
*/
@@ -40,14 +40,14 @@ class KScriptAction : public TQObject, public KScriptClientInterface {
public:
- KScriptAction( const TQString &scriptDesktopFile, TQObject *interface, KActionCollection *ac );
+ KScriptAction( const TQString &scriptDesktopFile, TQObject *interface, TDEActionCollection *ac );
virtual ~KScriptAction();
/**
* KAction for the current script
*/
- KAction *action();
+ TDEAction *action();
/**
* Returns the validity of the current script.
@@ -75,7 +75,7 @@ private slots:
void scriptFinished();
private:
- KAction *m_action;
+ TDEAction *m_action;
TQString m_scriptName;
TQString m_scriptType;
TQString m_scriptFile;
@@ -99,7 +99,7 @@ public:
/**
* Create a script manager that is attached to an action collection.
*/
- KScriptActionManager( TQObject *parent, KActionCollection *ac );
+ KScriptActionManager( TQObject *parent, TDEActionCollection *ac );
~KScriptActionManager();
/**
@@ -110,7 +110,7 @@ public:
* the manager will search in $KDEPATH/data/coolapp/data for all desktop
* files that are scripts.
*/
- TQPtrList<KAction> scripts( TQObject *interface, const TQStringList &dirs = TQStringList() ) const;
+ TQPtrList<TDEAction> scripts( TQObject *interface, const TQStringList &dirs = TQStringList() ) const;
signals:
/**
@@ -136,6 +136,6 @@ signals:
private:
mutable TQPtrList<KScriptAction> m_actions;
- KActionCollection *m_ac;
+ TDEActionCollection *m_ac;
};
#endif
@@ -24,14 +24,14 @@
class TQTimer;
/**
-* Connects a KAction to a script runner.
+* Connects a TDEAction to a script runner.
*
* @author ian geiser geiseri@sourcextreme.com
@@ -40,14 +40,14 @@ class KScriptAction : public TQObject, public KScriptClientInterface {
virtual ~KScriptAction();
/**
- * KAction for the current script
+ * TDEAction for the current script
*/